pub struct PlayerHeight(/* private fields */);Trait Implementations
Sourceimpl Component for PlayerHeight
impl Component for PlayerHeight
Sourceconst STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
Sourcefn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
Called when registering this component, allowing mutable access to its
ComponentHooks.Auto Trait Implementations
impl Freeze for PlayerHeight
impl RefUnwindSafe for PlayerHeight
impl Send for PlayerHeight
impl Sync for PlayerHeight
impl Unpin for PlayerHeight
impl UnsafeUnpin for PlayerHeight
impl UnwindSafe for PlayerHeight